@@ -286,7 +286,7 @@ class R3sponse(object):
 			except: a=1
 			try:  del response["success"]
 			except: a=1
-			response = self.serializable(response)
+			response = self.serialize(response)
 			return self.success_response(message, response)
 		else:
 			return self.error_response(response["error"])
